<?php
/**
 * Post Related Functions.
 * @author  Kudrat E Khuda
 * @author url  themenextlevel.com
 * @package million-shades

 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// The Metabox class
class Million_Shades_Post_Metaboxes {
	private $post_types;

	/**
	 * Metabox constructor
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'add_meta_boxes', array( $this, 'million_shades_add_custom_box' ));
		add_action( 'pre_post_update', array( $this, 'million_shades_save_custom_meta_more') );
		add_action( 'pre_post_update', array( $this, 'million_shades_save_custom_meta' ));

		// Load scripts for the metabox
		add_action( 'admin_enqueue_scripts', array( $this, 'million_shades_metabox_color_enqueue' ) );
		
		
	}
	
/**
 * Add Meta Box
 *
 */



public function million_shades_add_custom_box() {
	
	$id = array('nl-page-layout','nl-page-layout','nl-hide-and-show'
	,'nl-hide-and-show');
	
	$title = array(__('Select Layout','million-shades'),__('Select Layout','million-shades'),__('Page Header','million-shades'),__('Page Header','million-shades'));
	
	$callback = array('million_shades_page_layout','million_shades_page_layout','million_shades_hide_and_show','million_shades_hide_and_show');
	
	$screen = array('page','post','page','post');
	
	$context = array('side','side','normal','normal');
	
	$priority = array('default','default','high','high');
	
	
	for($i=0; $i < 4; $i++) {
		
		
		add_meta_box( $id[$i], $title[$i], array( $this, $callback[$i] ), $screen[$i], $context[$i], $priority[$i]);
		
	}
	
}

/* ======================================================================== */
public function million_shades_get_default_page_layouts() {

	$page_layout = array(
		'default-layout' => array(
			'id'    => 'million_shades_page_layout',
			'value' => 'default',
			'label' => __( 'Default', 'million-shades' )
		),
		'rightbar'       => array(
			'id'    => 'million_shades_page_layout',
			'value' => 'rightbar',
			'label' => __( 'Rightbar', 'million-shades' )
		),
		'leftbar'        => array(
			'id'    => 'million_shades_page_layout',
			'value' => 'leftbar',
			'label' => __( 'Leftbar', 'million-shades' )
		),
		
		'center'         => array(
			'id'    => 'million_shades_page_layout',
			'value' => 'nosidebar',
			'label' => __( 'No Sidebar', 'million-shades' )
		)
	);

	return $page_layout;

}

/* ========================================================================
 *
 * Displays metabox to for select layout option
 *
 * ======================================================================== */
 
public function million_shades_page_layout() {
	global $post;

	$page_layout = $this->million_shades_get_default_page_layouts();
	

	// Use nonce for verification  
	wp_nonce_field( basename( __FILE__ ), 'nl_meta_box_nonce' );

	foreach ( $page_layout as $field ) {
		$layout_meta = get_post_meta( $post->ID, $field['id'], true );
		if ( empty( $layout_meta ) ) {
			$layout_meta = 'default';
		}
		?>
        <label class="nl-post-format-icon">
            <input class="nl-post-format" type="radio" name="<?php echo esc_attr($field['id']); ?>" value="<?php echo esc_attr($field['value']); ?>" <?php checked( $field['value'], $layout_meta ); ?>/>
			<?php echo esc_html($field['label']); ?></label><br />
		<?php
	}
	
	
	
}

public function million_shades_hide_and_show() {
	global $post;

	
 $meta = get_post_meta( $post->ID );
	
		?>
    

	<p>
	<label for="million_shades_hide_page_header">
            <input type="checkbox" name="million_shades_hide_page_header" id="million_shades_hide_page_header" value="yes" <?php if ( isset ( $meta['million_shades_hide_page_header'] ) ) checked( $meta['million_shades_hide_page_header'][0], 'yes' ); ?> />
            <?php esc_html_e( 'Hide Page Header', 'million-shades' )?>
        </label>
	</p>
	<p>
    <label for="million_shades_page_header_bg_color" class="million_shades_page_header_bg_color"><?php esc_html_e( 'Page Header Background Color', 'million-shades' )?></label>
    <input name="million_shades_page_header_bg_color" type="text" value="<?php if ( isset ( $meta['million_shades_page_header_bg_color'] ) ) echo esc_attr($meta['million_shades_page_header_bg_color'][0]); ?>" class="page_header_bg_color" />
	</p>
	
	
	
	<?php
}	



/* ========================================================================
 *
 * save the custom metabox data
 *
 * ======================================================================== */
public function million_shades_save_custom_meta( $post_id ) {

	$page_layout = $this->million_shades_get_default_page_layouts();

	// Verify the nonce before proceeding.
	if ( ! isset( $_POST['nl_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['nl_meta_box_nonce'], basename( __FILE__ ) ) ) {
		return;
	}

	// Stop WP from clearing custom fields on autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	if ( 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}
	} elseif ( ! current_user_can( 'edit_post', $post_id ) ) {
		return $post_id;
	}

	foreach ( $page_layout as $field ) {
		//Execute this saving function
		$old = get_post_meta( $post_id, $field['id'], true );
		
		$new = isset( $_POST[ $field['id'] ] ) ? $_POST[ $field['id'] ] : 'default';
		
		$new = million_shades_sanitize_sidebar($new);
		
		if ( $new && $new != $old ) {
			update_post_meta( $post_id, $field['id'], $new );
		} elseif ( '' == $new && $old ) {
			delete_post_meta( $post_id, $field['id'], $old );
		}
	} // end foreach  
		
	
}



public function million_shades_save_custom_meta_more( $post_id ) {

	

	// Verify the nonce before proceeding.
	if ( ! isset( $_POST['nl_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['nl_meta_box_nonce'], basename( __FILE__ ) ) ) {
		return;
	}

	// Stop WP from clearing custom fields on autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	if ( 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}
	} elseif ( ! current_user_can( 'edit_post', $post_id ) ) {
		return $post_id;
	}

	
		//Execute this saving function
	
		
		$old = get_post_meta( $post_id, 'million_shades_hide_page_header', true );
		$new = million_shades_sanitize_yes_no( $_POST['million_shades_hide_page_header'] ) ;
		if ( $new && $new != $old ) {
			update_post_meta( $post_id, 'million_shades_hide_page_header', $new );
		} elseif ( '' == $new && $old ) {
			delete_post_meta( $post_id, 'million_shades_hide_page_header', $old );
		}
		


		if( isset( $_POST[ 'million_shades_page_header_bg_color' ] ) ) {
				$million_shades_page_header_background_color = sanitize_hex_color( $_POST['million_shades_page_header_bg_color'] );
    update_post_meta( $post_id, 'million_shades_page_header_bg_color', $million_shades_page_header_background_color );
	}

	
	
}



public function million_shades_metabox_color_enqueue() {
		global $pagenow;
	$posts_all = array('post', 'page');
    // get current admin screen, or null
    $screen = get_current_screen();
    // verify admin screen object
    if (is_object($screen)) {
        // enqueue only for specific post types
        if (in_array($screen->post_type, $posts_all)) {
     
        wp_enqueue_style( 'wp-color-picker' );
        wp_enqueue_script( 'million_shades_meta_box_color_js', get_template_directory_uri() . '/inc/js/meta-box-color.js', array( 'wp-color-picker' ) );
		}
	}
}


public function million_shades_admin_styles(){
   
   $posts_all = array('post', 'page');
     // get current admin screen, or null
    $screen = get_current_screen();
    // verify admin screen object
    if (is_object($screen)) {
        // enqueue only for specific post types
        if (in_array($screen->post_type, $posts_all)) {
        wp_enqueue_style( 'million_shades_meta_box_styles', get_template_directory_uri() . '/assets/css/meta-box-styles.css' );
    	}
	}
}

}

$MS_Post_Metaboxes = new Million_Shades_Post_Metaboxes();